@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import List
 
 from .vars_manager import VarsManager
 from .workdir_manager import WorkDirManager
@@ -12,3 +13,7 @@ class KernelDefinition(ABC):
     @abstractmethod
     def create_workdir_manager(self, workdir: str) -> WorkDirManager:
         raise NotImplementedError
+
+    @property
+    def kernel_options(self) -> List[str]:
+        return []
