@@ -5,29 +5,63 @@ from typing import Any, Dict, List, Optional
 from uuid import UUID
 
 from asyncblink import signal  # type: ignore
-from fastapi import (APIRouter, BackgroundTasks, Depends, HTTPException,
-                     Request, Response, WebSocket, status)
+from fastapi import (
+    APIRouter,
+    BackgroundTasks,
+    Depends,
+    HTTPException,
+    Request,
+    Response,
+    WebSocket,
+    status,
+)
 from fastapi.encoders import jsonable_encoder
 from fastapi.logger import logger
+import jsonschema
 
-from jupyter_d1.signals import (CELL_ADDED, CELL_DELETED, CELL_EXECUTION_INPUT,
-                                CELL_EXECUTION_REPLY, CELL_EXECUTION_REQUEST,
-                                CELL_STREAM, CELL_UPDATE, COMPLETE_REPLY,
-                                CONTROL_CHANNEL, HB_CHANNEL, HISTORY_REPLY,
-                                IOPUB_CHANNEL, KERNEL_INTERRUPTED,
-                                KERNEL_RESTARTED, METADATA_UPDATE,
-                                PAYLOAD_PAGE, SCRATCH_UPDATE, SHELL_CHANNEL,
-                                STDIN_CHANNEL, VARS_UPDATE)
+from jupyter_d1.signals import (
+    CELL_ADDED,
+    CELL_DELETED,
+    CELL_EXECUTION_INPUT,
+    CELL_EXECUTION_REPLY,
+    CELL_EXECUTION_REQUEST,
+    CELL_STREAM,
+    CELL_UPDATE,
+    COMPLETE_REPLY,
+    CONTROL_CHANNEL,
+    HB_CHANNEL,
+    HISTORY_REPLY,
+    IOPUB_CHANNEL,
+    KERNEL_INTERRUPTED,
+    KERNEL_RESTARTED,
+    METADATA_UPDATE,
+    PAYLOAD_PAGE,
+    SCRATCH_UPDATE,
+    SHELL_CHANNEL,
+    STDIN_CHANNEL,
+    VARS_UPDATE,
+)
 
 from ..d1_response import D1Encoder, D1Response
 from ..deps import read_access_websocket, write_access, write_access_websocket
-from ..models.cell import (CellAdd, CellKernelMessageWrapper, CellsWrapper,
-                           CellUpdate, CellWrapper)
+from ..models.cell import (
+    CellAdd,
+    CellKernelMessageWrapper,
+    CellsWrapper,
+    CellUpdate,
+    CellWrapper,
+)
 from ..models.code_complete import CodeComplete
-from ..models.kernel_message import (KernelMessage, KernelMessagesWrapper,
-                                     KernelMessageWrapper)
-from ..models.kernel_variable import (KernelVariable, KernelVariablesWrapper,
-                                      KernelVariableWrapper)
+from ..models.kernel_message import (
+    KernelMessage,
+    KernelMessagesWrapper,
+    KernelMessageWrapper,
+)
+from ..models.kernel_variable import (
+    KernelVariable,
+    KernelVariablesWrapper,
+    KernelVariableWrapper,
+)
 from ..models.notebook import NotebookPath, NotebooksWrapper, NotebookWrapper
 from ..models.scratch import ScratchCode
 from ..settings import settings
@@ -419,9 +453,12 @@ async def upload_notebook(
 ) -> Any:
     body = await request.body()
     path_info = format_file_path(directory, filename)
-    manager.upload_notebook(
-        body, path_info["directory"], path_info["filename"]
-    )
+    try:
+        manager.upload_notebook(
+            body, path_info["directory"], path_info["filename"]
+        )
+    except (jsonschema.exceptions.ValidationError, AttributeError) as e:
+        raise HTTPException(400, f"Failed to parse notebook: {type(e)} {e}")
     return NotebookPath(path=path_info["relative_path"])
 
 
@@ -450,17 +487,20 @@ async def upload_and_open_notebook(
         filename = path_info["filename"]
     if directory is None:
         directory = settings.ROOT_DIR
-    nb_uuid = await manager.add_notebook_json(
-        body,
-        kspec_name=kspec_name,
-        directory=directory,
-        filename=filename,
-        working_directory=working_directory,
-        autosave=autosave,
-    )
+    try:
+        nb_uuid = await manager.add_notebook_json(
+            body,
+            kspec_name=kspec_name,
+            directory=directory,
+            filename=filename,
+            working_directory=working_directory,
+            autosave=autosave,
+        )
 
-    nb = manager.get_notebook_node(nb_uuid)
-    return NotebookWrapper(notebook=nb.dict())
+        nb = manager.get_notebook_node(nb_uuid)
+        return NotebookWrapper(notebook=nb.dict())
+    except (jsonschema.exceptions.ValidationError, AttributeError) as e:
+        raise HTTPException(400, f"Failed to parse notebook: {type(e)} {e}")
 
 
 @router.get(
@@ -481,13 +521,17 @@ async def open_notebook(
     )
     if not path.exists(abs_path):
         raise HTTPException(status_code=404, detail=f"File not found")
-    nb_uuid = await manager.open_notebook(
-        abs_path, kspec_name=kspec_name, working_directory=working_directory
-    )
+    try:
+        nb_uuid = await manager.open_notebook(
+            abs_path, kspec_name=kspec_name, working_directory=working_directory
+        )
 
-    nb = manager.get_notebook_node(nb_uuid)
-    return NotebookWrapper(notebook=nb.dict())
+        nb = manager.get_notebook_node(nb_uuid)
+        return NotebookWrapper(notebook=nb.dict())
 
+    except (jsonschema.exceptions.ValidationError, AttributeError) as e:
+        raise HTTPException(400, f"Failed to parse notebook: {type(e)} {e}")
+    
 
 @router.post(
     "/create",
