@@ -3,8 +3,13 @@ from pprint import pformat
 from asyncblink import signal  # type: ignore
 from fastapi.logger import logger
 
-from jupyter_d1.signals import (CONTROL_CHANNEL, HB_CHANNEL, IOPUB_CHANNEL,
-                                SHELL_CHANNEL, STDIN_CHANNEL)
+from jupyter_d1.signals import (
+    CONTROL_CHANNEL,
+    HB_CHANNEL,
+    IOPUB_CHANNEL,
+    SHELL_CHANNEL,
+    STDIN_CHANNEL,
+)
 
 log_to_file = False
 log_to_logger = False
