@@ -13,15 +13,30 @@ from fastapi.logger import logger
 
 from jupyter_d1.commands import execute_d1_command
 from jupyter_d1.dav import dav_manager
-from jupyter_d1.signals import (CELL_ADDED, CELL_DELETED, CELL_EXECUTION_INPUT,
-                                CELL_EXECUTION_REPLY, CELL_EXECUTION_REQUEST,
-                                CELL_STREAM, CELL_UPDATE, COMPLETE_REPLY,
-                                CONTROL_CHANNEL, HB_CHANNEL, HISTORY_REPLY,
-                                IOPUB_CHANNEL, KERNEL_INTERRUPTED,
-                                KERNEL_RESTARTED, METADATA_UPDATE,
-                                NOTEBOOKS_UPDATED, PAYLOAD_PAGE,
-                                SCRATCH_UPDATE, SHELL_CHANNEL, STDIN_CHANNEL,
-                                VAR_DETAILS, VARS_UPDATE)
+from jupyter_d1.signals import (
+    CELL_ADDED,
+    CELL_DELETED,
+    CELL_EXECUTION_INPUT,
+    CELL_EXECUTION_REPLY,
+    CELL_EXECUTION_REQUEST,
+    CELL_STREAM,
+    CELL_UPDATE,
+    COMPLETE_REPLY,
+    CONTROL_CHANNEL,
+    HB_CHANNEL,
+    HISTORY_REPLY,
+    IOPUB_CHANNEL,
+    KERNEL_INTERRUPTED,
+    KERNEL_RESTARTED,
+    METADATA_UPDATE,
+    NOTEBOOKS_UPDATED,
+    PAYLOAD_PAGE,
+    SCRATCH_UPDATE,
+    SHELL_CHANNEL,
+    STDIN_CHANNEL,
+    VAR_DETAILS,
+    VARS_UPDATE,
+)
 
 from ..d1_response import D1Encoder, d1_pairs_hook
 from ..kernels import VarsManager, WorkDirManager, get_kernel_definition
@@ -307,21 +322,31 @@ class NotebookManager:
             working_kspec_name = list(
                 filter(lambda x: "python" in x, available_names)
             ).pop()
-
-        work_dir = notebook_node.metadata.jupyter_d1.working_directory
-        await self.kmanager.start_kernel(
-            kernel_name=working_kspec_name, uuid=nb_uuid, directory=work_dir
+        working_kspec_name, kernelspec = self.kmanager.get_kernelspec_by_name(
+            kspec_name
         )
 
-        kernel_language = self.kmanager.get_kernelspec(nb_uuid).language
-        kernel_definition = get_kernel_definition(kernel_language)
+        work_dir = notebook_node.metadata.jupyter_d1.working_directory
+
+        kernel_definition = get_kernel_definition(
+            kernelspec["spec"]["language"]
+        )
         vars_manager: Optional[VarsManager] = None
         workdir_manager: Optional[WorkDirManager] = None
+        kernel_options = []
         if kernel_definition is not None:
             vars_manager = kernel_definition.create_vars_manager()
             workdir_manager = kernel_definition.create_workdir_manager(
                 work_dir
             )
+            kernel_options = kernel_definition.kernel_options
+
+        await self.kmanager.start_kernel(
+            kernel_name=working_kspec_name,
+            uuid=nb_uuid,
+            directory=work_dir,
+            kernel_options=kernel_options,
+        )
 
         if work_dir is not None:
             dav_manager.add_provider(work_dir, nb_uuid)
