@@ -7,8 +7,8 @@ from typing import Dict
 from unittest import TestCase
 
 import pytest  # type: ignore
-from async_asgi_testclient import (  # type: ignore
-    TestClient as WebSocketTestClient
+from async_asgi_testclient import (
+    TestClient as WebSocketTestClient,  # type: ignore
 )
 from fastapi import WebSocket
 from fastapi.testclient import TestClient
@@ -17,8 +17,13 @@ from pytest_mock import MockFixture  # type: ignore
 from jupyter_d1.settings import settings
 
 from .test_notebooks_websocket import upload_notebook
-from .utils import (get_permissionless_token, get_read_only_token,
-                    get_superuser_token, wait_for_event, workdir_1)
+from .utils import (
+    get_permissionless_token,
+    get_read_only_token,
+    get_superuser_token,
+    wait_for_event,
+    workdir_1,
+)
 
 is_mac = platform.system().startswith("Darwin")
 
