@@ -1316,6 +1316,57 @@ class TestNotebook:
             == settings.ROOT_DIR
         )
 
+    def test_upload_invalid_notebook(
+        self, client: TestClient, superuser_token_headers: Dict[str, str]
+    ):
+        """
+        Invalid notebook should return 400, and not cause a 500
+        """
+        response = client.post(
+            "/notebooks/upload",
+            params={"filename": "name.ipynb", "autosave": False},
+            data="{}",
+            headers=superuser_token_headers,
+        )
+        assert response.status_code == 400
+        assert response.json()["detail"] == \
+            "Failed to parse notebook: <class 'AttributeError'> cells"
+
+    def test_open_invalid_notebook(
+        self, client: TestClient, superuser_token_headers: Dict[str, str]
+    ):
+        """
+        Invalid notebook should return 400, and not cause a 500
+        """
+        with open(f"{settings.ROOT_DIR}/name1l.ipynb", "w") as f:
+            f.write("{}")
+
+        response = client.get(
+            "/notebooks/open/",
+            params={"filepath": "name1l.ipynb"},
+            data="{}",
+            headers=superuser_token_headers,
+        )
+        assert response.status_code == 400
+        assert response.json()["detail"] == \
+            "Failed to parse notebook: <class 'AttributeError'> cells"
+
+    def test_upload_and_open_invalid_notebook(
+        self, client: TestClient, superuser_token_headers: Dict[str, str]
+    ):
+        """
+        Invalid notebook should return 400, and not cause a 500
+        """
+        response = client.post(
+            "/notebooks/upload_and_open",
+            params={"filename": "name.ipynb", "autosave": False},
+            data="{}",
+            headers=superuser_token_headers,
+        )
+        assert response.status_code == 400
+        assert response.json()["detail"] == \
+            "Failed to parse notebook: <class 'AttributeError'> cells"
+
 
 @pytest.mark.usefixtures("clear_notebooks", "clear_notebook_directory")
 class TestNotebookPermissions:
